@@ -22,6 +22,10 @@ pub enum Error {
   },
   #[error(transparent)]
   Other(Box<dyn std::error::Error + Sync + Send + 'static>),
+  #[error("invalid data url '{specifier}': '{error}'")]
+  InvalidDataUrl { specifier: String, error: String },
+  #[error("scheme '{scheme}' is not supported: '{specifier}'")]
+  InvalidScheme { scheme: String, specifier: String },
 }
 
 pub fn reqwest_error(specifier: String, error: reqwest::Error) -> Error {
